==> nextcloud-14.0.1.tgz: nextcloud/apps/support/l10n/lt_LT.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Nuoroda:",
    "Password:" : "Slaptažodis:",
    "Generating system report failed." : "Sistemos ataskaitos generavimas patyrė nesėkmę.",
    "Nextcloud Subscription" : "Nextcloud prenumerata",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Jūsų serveris neturi Nextcloud prenumeratos arba pasibaigė jūsų prenumeratos galiojimo laikas.",
    "Thank you," : "Ačiū,",
    "Your Nextcloud team" : "Jūsų Nextcloud komanda",
    "Your Nextcloud server Subscription is expired" : "Pasibaigė jūsų Nextcloud prenumeratos galiojimo laikas",
    "Your Nextcloud server Subscription is expired!" : "Pasibaigė jūsų Nextcloud serverio prenumeratos galiojimo laikas!",
    "Subscription key:" : "Prenumeratos raktas:",
    "_For %n users_::_For %n users_" : ["Skirta %n naudotojui","Skirta %n naudotojams","Skirta %n naudotojų","Skirta %n naudotojui"],
    "Update subscription key" : "Atnaujinti prenumeratos raktą",
    "System information" : "Sistemos informacija",
    "More information" : "Daugiau informacijos",
    "Forum" : "Forumas",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud yra laisvoji programinė įranga, kuri yra palaikoma labai aktyvios bendruomenės. Norėdami užduoti klausimus ir diskutuoti su kitais, užsiregistruokite forume.",
    "Nextcloud forum" : "Nextcloud forumas",
    "GitHub" : "GitHub",
    "Subscription key" : "Prenumeratos raktas",
    "The subscription key was invalid." : "Prenumeratos raktas buvo neteisingas.",
    "The subscription key had an invalid format." : "Prenumeratos raktas buvo neteisingo formato.",
    "News" : "Naujienos",
    "Follow us on Google+" : "Sekite mus Google+",
    "Like our Facebook page" : "Spauskite \"Patinka\" mūsų Facebook puslapyje",
    "Follow us on Twitter" : "Sekite mus Twitter",
    "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
    "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-20.0.8p0.tgz: nextcloud/apps/support/l10n/lt_LT.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Nuoroda:",
    "Password:" : "Slaptažodis:",
    "Generating system report failed." : "Sistemos ataskaitos generavimas patyrė nesėkmę.",
    "Nextcloud Subscription" : "Nextcloud prenumerata",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Jūsų serveris neturi Nextcloud prenumeratos arba pasibaigė jūsų prenumeratos galiojimo laikas.",
    "Your Nextcloud Subscription has expired!" : "Pasibaigė jūsų Nextcloud prenumeratos galiojimo laikas!",
    "Your server has no Nextcloud Subscription" : "Jūsų serveris neturi Nextcloud prenumeratos",
    "Learn more now" : "Sužinokite daugiau dabar",
    "Dear admin," : "Brangus administratoriau,",
    "Thank you," : "Ačiū,",
    "Your Nextcloud team" : "Jūsų Nextcloud komanda",
    "Your Nextcloud server Subscription is expired" : "Pasibaigė jūsų Nextcloud prenumeratos galiojimo laikas",
    "Your Nextcloud server Subscription is expired!" : "Pasibaigė jūsų Nextcloud serverio prenumeratos galiojimo laikas!",
    "Support" : "Palaikymas",
    "Subscription key:" : "Prenumeratos raktas:",
    "_Expires in %n year_::_Expires in %n years_" : ["Baigia galioti po %n metų","Baigia galioti po %n metų","Baigia galioti po %n metų","Baigia galioti po %n metų"],
    "_Expires in %n month_::_Expires in %n months_" : ["Baigia galioti po %n mėnesio","Baigia galioti po %n mėnesių","Baigia galioti po %n mėnesių","Baigia galioti po %n mėnesio"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Baigia galioti po %n savaitės","Baigia galioti po %n savaičių","Baigia galioti po %n savaičių","Baigia galioti po %n savaitės"],
    "_Expires in %n day_::_Expires in %n days_" : ["Baigia galioti po %n dienos","Baigia galioti po %n dienų","Baigia galioti po %n dienų","Baigia galioti po %n dienos"],
    "_For %n users_::_For %n users_" : ["Skirta %n naudotojui","Skirta %n naudotojams","Skirta %n naudotojų","Skirta %n naudotojui"],
    "Update subscription key" : "Atnaujinti prenumeratos raktą",
    "System information" : "Sistemos informacija",
    "Unsupported" : "Nepalaikoma",
    "Advantages" : "Privalumai",
    "More information" : "Daugiau informacijos",
    "Subscription benefits" : "Prenumeratos naudos",
    "Commmunity support" : "Bendruomenės palaikymas",
    "Forum" : "Forumas",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud yra laisvoji programinė įranga, kuri yra palaikoma labai aktyvios bendruomenės. Norėdami užduoti klausimus ir diskutuoti su kitais, užsiregistruokite forume.",
    "GitHub" : "GitHub",
    "Nextcloud forum" : "Nextcloud forumas",
    "Subscription key" : "Prenumeratos raktas",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Jeigu turite aktyvią Nextcloud prenumeratą, įveskite čia savo prenumeratos raktą.",
    "The subscription key was invalid." : "Prenumeratos raktas buvo neteisingas.",
    "The subscription key had an invalid format." : "Prenumeratos raktas buvo neteisingo formato.",
    "News" : "Naujienos",
    "Like our Facebook page" : "Spauskite \"Patinka\" mūsų Facebook puslapyje",
    "Follow us on Twitter" : "Sekite mus Twitter",
    "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
    "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
